# Example Package

This is a simple example package. You can use
[bigsansar](https://bigsansar.com)
to write your content.

[youtube](https://youtube.com/bigsansar)

install 'bigsansar.apps.BigsansarConfig' app in to django 

then

use this commands 

python3 manage.py createuser 

and get 1000 test user 

default password : bp787898